Class: Scaled::Resources::DeviceRoutes
- Inherits:
-
Object
- Object
- Scaled::Resources::DeviceRoutes
- Defined in:
- lib/scaled/resources/device_routes.rb
Overview
API wrapper for per-device subnet routes. API-обгортка для маршрутів (subnet routes) окремого device.
Instance Method Summary collapse
-
#get(device_id) ⇒ Hash, ...
Note: read-only; reveals subnet routers and exit nodes for the device.
- #initialize(client) ⇒ void constructor
Constructor Details
#initialize(client) ⇒ void
10 11 12 |
# File 'lib/scaled/resources/device_routes.rb', line 10 def initialize(client) @client = client end |
Instance Method Details
#get(device_id) ⇒ Hash, ...
Note: read-only; reveals subnet routers and exit nodes for the device. Нотатка: read-only; показує subnet-routers та exit-nodes для device.
18 19 20 |
# File 'lib/scaled/resources/device_routes.rb', line 18 def get(device_id) @client.get("/device/#{device_id}/routes") end |